@@ -36,6 +36,7 @@
 #include "audio/audiooutput.h"
 #include "audio/audiodataoutput.h"
 #include "audio/volumefadereffect.h"
+#include "config.h"
 #include "devicemanager.h"
 #include "effect.h"
 #include "effectmanager.h"
@@ -47,15 +48,8 @@
 #ifdef PHONON_EXPERIMENTAL
 #include "video/videodataoutput.h"
 #endif
-#ifndef PHONON_NO_GRAPHICSVIEW
-#include "video/videographicsobject.h"
-#endif
 #include "video/videowidget.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN2(phonon_vlc, Phonon::VLC::Backend)
-#endif
-
 namespace Phonon
 {
 namespace VLC
@@ -111,12 +105,10 @@ Backend::Backend(QObject *parent, const QVariantList &)
             const QString id = QString("org.kde.phonon.%1").arg(qApp->applicationName());
             const QString version = qApp->applicationVersion();
             QString icon;
-#if QT_VERSION >= QT_VERSION_CHECK(4, 7, 0)
             if (!qApp->windowIcon().isNull()){
                 // Try to get the fromTheme() name of the QIcon.
                 icon = qApp->windowIcon().name();
             }
-#endif
             if (icon.isEmpty()) {
                 // If we failed to get a proper icon name, use the appname instead.
                 icon = qApp->applicationName().toLower();
@@ -147,13 +139,14 @@ Backend::Backend(QObject *parent, const QVariantList &)
         fatal() << "Phonon::VLC::vlcInit: Failed to initialize VLC";
     }
 
-    // Initialise PulseAudio support
-    PulseSupport *pulse = PulseSupport::getInstance();
 #if (LIBVLC_VERSION_INT < LIBVLC_VERSION(2, 2, 2, 0))
     // VLC 2.2 changed the stream creation order around internally which breaks
     // the Pulseaudio hijacking. Since VLC upstream doesn't feel like giving us
     // any more property control we now consider this feature unsupported. As
     // such whatever properties VLC sets will be what pulse knows about us.
+
+    // Initialise PulseAudio support
+    PulseSupport *pulse = PulseSupport::getInstance();
     pulse->enable(true);
     connect(pulse, SIGNAL(objectDescriptionChanged(ObjectDescriptionType)),
             SIGNAL(objectDescriptionChanged(ObjectDescriptionType)));
@@ -194,10 +187,8 @@ QObject *Backend::createObject(BackendInterface::Class c, QObject *parent, const
     case VideoDataOutputClass:
         return new VideoDataOutput(parent);
 #endif
-#ifndef PHONON_NO_GRAPHICSVIEW
     case VideoGraphicsObjectClass:
-        return new VideoGraphicsObject(parent);
-#endif
+        return nullptr; // No longer supported
     case EffectClass:
         return effectManager()->createEffect(args[0].toInt(), parent);
     case VideoWidgetClass:
